@@ -42,37 +42,39 @@
 #include "util.h"
 #include "fmt.h"
 #include "DownloadEngine.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
-BtStopDownloadCommand::BtStopDownloadCommand
-(cuid_t cuid,
- RequestGroup* requestGroup,
- DownloadEngine* e,
- time_t timeout)
-  : TimeBasedCommand(cuid, e, 1),
-    requestGroup_(requestGroup),
-    timeout_(timeout)
-{}
+BtStopDownloadCommand::BtStopDownloadCommand(cuid_t cuid,
+                                             RequestGroup* requestGroup,
+                                             DownloadEngine* e,
+                                             std::chrono::seconds timeout)
+    : TimeBasedCommand(cuid, e, 1_s),
+      requestGroup_(requestGroup),
+      timeout_(std::move(timeout))
+{
+}
 
 void BtStopDownloadCommand::preProcess()
 {
-  if(btRuntime_->isHalt() || pieceStorage_->downloadFinished()) {
+  if (btRuntime_->isHalt() || pieceStorage_->downloadFinished()) {
     enableExit();
   }
-  if(checkPoint_.difference(global::wallclock()) >= timeout_) {
-    A2_LOG_NOTICE(fmt("GID#%s Stop downloading torrent due to"
-                      " --bt-stop-timeout option.",
-                      util::itos(requestGroup_->getGID()).c_str()));
+  if (checkPoint_.difference(global::wallclock()) >= timeout_) {
+    A2_LOG_NOTICE(fmt(_("GID#%s Stop downloading torrent due to"
+                        " --bt-stop-timeout option."),
+                      GroupId::toHex(requestGroup_->getGID()).c_str()));
     requestGroup_->setForceHaltRequested(true);
-    getDownloadEngine()->setRefreshInterval(0);
+    getDownloadEngine()->setRefreshInterval(std::chrono::milliseconds(0));
     enableExit();
   }
 }
 
 void BtStopDownloadCommand::process()
 {
-  if(requestGroup_->calculateStat().getDownloadSpeed() > 0) {
+  NetStat& stat = requestGroup_->getDownloadContext()->getNetStat();
+  if (stat.calculateDownloadSpeed() > 0) {
     checkPoint_ = global::wallclock();
   }
 }
