@@ -32,22 +32,25 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_INITIATE_CONNECTION_COMMAND_H_
-#define _D_INITIATE_CONNECTION_COMMAND_H_
+#ifndef D_INITIATE_CONNECTION_COMMAND_H
+#define D_INITIATE_CONNECTION_COMMAND_H
 
 #include "AbstractCommand.h"
 
 namespace aria2 {
 
+struct BackupConnectInfo;
+class ConnectCommand;
+
 class InitiateConnectionCommand : public AbstractCommand {
 protected:
   /**
    * Connect to the server.
    * This method just send connection request to the server.
-   * Using nonblocking mode of socket, this funtion returns immediately
+   * Using nonblocking mode of socket, this function returns immediately
    * after send connection packet to the server.
    */
-  virtual bool executeInternal();
+  virtual bool executeInternal() CXX11_OVERRIDE;
 
   // hostname and port are the hostname and port number we are going
   // to connect. If proxy server is used, these values are hostname
@@ -55,24 +58,33 @@ protected:
   // use this address this time.  resolvedAddresses are all addresses
   // resolved.  proxyRequest is set if we are going to use proxy
   // server.
-  virtual Command* createNextCommand
-  (const std::string& hostname, const std::string& addr, uint16_t port,
-   const std::vector<std::string>& resolvedAddresses,
-   const SharedHandle<Request>& proxyRequest) = 0;
+  virtual std::unique_ptr<Command>
+  createNextCommand(const std::string& hostname, const std::string& addr,
+                    uint16_t port,
+                    const std::vector<std::string>& resolvedAddresses,
+                    const std::shared_ptr<Request>& proxyRequest) = 0;
+
+  void setConnectedAddrInfo(const std::shared_ptr<Request>& req,
+                            const std::string& hostname,
+                            const std::shared_ptr<SocketCore>& socket);
+
+  std::shared_ptr<BackupConnectInfo>
+  createBackupIPv4ConnectCommand(const std::string& hostname,
+                                 const std::string& ipaddr, uint16_t port,
+                                 Command* mainCommand);
+
+  void setupBackupConnection(const std::string& hostname,
+                             const std::string& addr, uint16_t port,
+                             ConnectCommand* c);
 
-  void setConnectedAddrInfo
-  (const SharedHandle<Request>& req,
-   const std::string& hostname,
-   const SharedHandle<SocketCore>& socket);
 public:
-  InitiateConnectionCommand(cuid_t cuid, const SharedHandle<Request>& req,
-                            const SharedHandle<FileEntry>& fileEntry,
-                            RequestGroup* requestGroup,
-                            DownloadEngine* e);
+  InitiateConnectionCommand(cuid_t cuid, const std::shared_ptr<Request>& req,
+                            const std::shared_ptr<FileEntry>& fileEntry,
+                            RequestGroup* requestGroup, DownloadEngine* e);
 
   virtual ~InitiateConnectionCommand();
 };
 
 } // namespace aria2
 
-#endif // _D_INITIATE_CONNECTION_COMMAND_H_
+#endif // D_INITIATE_CONNECTION_COMMAND_H
