@@ -1,3 +1,4 @@
+/* <!-- copyright */
 /*
  * aria2 - The high speed download utility
  *
@@ -30,39 +31,26 @@
  * version.  If you delete this exception statement from all source
  * files in the program, then also delete it here.
  */
+/* copyright --> */
+
 #ifndef D_LPD_MESSAGE_H
 #define D_LPD_MESSAGE_H
 
 #include "common.h"
 
 #include <string>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
 class Peer;
 
-class LpdMessage {
-private:
-  SharedHandle<Peer> peer_;
-  std::string infoHash_;
-public:
+struct LpdMessage {
+  std::shared_ptr<Peer> peer;
+  std::string infoHash;
   LpdMessage();
-
-  LpdMessage(const SharedHandle<Peer>& peer, const std::string& infoHash);
-
+  LpdMessage(const std::shared_ptr<Peer>& peer, const std::string& infoHash);
   ~LpdMessage();
-
-  const SharedHandle<Peer>& getPeer() const
-  {
-    return peer_;
-  }
-
-  const std::string& getInfoHash() const
-  {
-    return infoHash_;
-  }
 };
 
 } // namespace aria2
