@@ -36,33 +36,24 @@
 #define D_RANGE_BT_MESSAGE_VALIDATOR_H
 
 #include "BtMessageValidator.h"
-#include "RangeBtMessage.h"
-#include "bittorrent_helper.h"
 
 namespace aria2 {
 
+class RangeBtMessage;
+
 class RangeBtMessageValidator : public BtMessageValidator {
 private:
   const RangeBtMessage* message_;
   size_t numPiece_;
-  size_t pieceLength_;
-public:
-  RangeBtMessageValidator(const RangeBtMessage* message,
-                          size_t numPiece,
-                          size_t pieceLength):
-    message_(message),
-    numPiece_(numPiece),
-    pieceLength_(pieceLength) {}
+  int32_t pieceLength_;
 
-  virtual void validate()
-  {
-    bittorrent::checkIndex(message_->getIndex(), numPiece_);
-    bittorrent::checkBegin(message_->getBegin(), pieceLength_);
-    bittorrent::checkLength(message_->getLength());
-    bittorrent::checkRange(message_->getBegin(),
-                           message_->getLength(),
-                           pieceLength_);
-  }
+public:
+  RangeBtMessageValidator(const RangeBtMessage* message, size_t numPiece,
+                          int32_t pieceLength);
+
+  ~RangeBtMessageValidator();
+
+  virtual void validate() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
