@@ -9,28 +9,22 @@
 
 namespace aria2 {
 
-class InorderURISelectorTest:public CppUnit::TestFixture {
+class InorderURISelectorTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(InorderURISelectorTest);
   CPPUNIT_TEST(testSelect);
   CPPUNIT_TEST_SUITE_END();
+
 private:
   FileEntry fileEntry_;
 
-  SharedHandle<InorderURISelector> sel;
+  std::shared_ptr<InorderURISelector> sel;
 
 public:
   void setUp()
   {
-    static const char* urisSrc[] = {
-      "http://alpha/file",
-      "ftp://alpha/file",
-      "http://bravo/file"
-    };
-    std::vector<std::string> uris;
-    uris.assign(vbegin(urisSrc), vend(urisSrc));
-
-    fileEntry_.setUris(uris);
+    fileEntry_.setUris(
+        {"http://alpha/file", "ftp://alpha/file", "http://bravo/file"});
 
     sel.reset(new InorderURISelector());
   }
@@ -40,12 +34,11 @@ public:
   void testSelect();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(InorderURISelectorTest);
 
 void InorderURISelectorTest::testSelect()
 {
-  std::vector<std::pair<size_t, std::string> > usedHosts;
+  std::vector<std::pair<size_t, std::string>> usedHosts;
   CPPUNIT_ASSERT_EQUAL(std::string("http://alpha/file"),
                        sel->select(&fileEntry_, usedHosts));
   CPPUNIT_ASSERT_EQUAL(std::string("ftp://alpha/file"),
